pub enum MathExpr {
Show 34 variants
Ident {
value: String,
},
Number {
value: String,
},
Operator(MathOperator),
Text {
value: String,
},
Row {
children: Vec<MathExpr>,
},
Fenced {
open: Delimiter,
close: Delimiter,
body: Vec<MathExpr>,
},
Superscript {
base: Box<MathExpr>,
script: Box<MathExpr>,
},
Subscript {
base: Box<MathExpr>,
script: Box<MathExpr>,
},
Subsuperscript {
base: Box<MathExpr>,
sub: Box<MathExpr>,
sup: Box<MathExpr>,
},
Frac {
numerator: Box<MathExpr>,
denominator: Box<MathExpr>,
style: FracStyle,
},
Sqrt {
index: Option<Box<MathExpr>>,
body: Box<MathExpr>,
},
Overline {
body: Box<MathExpr>,
},
Underline {
body: Box<MathExpr>,
},
Overbrace {
body: Box<MathExpr>,
annotation: Option<Box<MathExpr>>,
},
Underbrace {
body: Box<MathExpr>,
annotation: Option<Box<MathExpr>>,
},
Overset {
over: Box<MathExpr>,
base: Box<MathExpr>,
},
Underset {
under: Box<MathExpr>,
base: Box<MathExpr>,
},
Accent {
kind: AccentKind,
body: Box<MathExpr>,
},
BigOperator {
op: MathOperator,
limits: LimitStyle,
lower: Option<Box<MathExpr>>,
upper: Option<Box<MathExpr>>,
},
Matrix {
rows: Vec<Vec<MathExpr>>,
delimiters: MatrixDelimiters,
},
Cases {
rows: Vec<CaseRow>,
},
Array {
columns: Vec<ColumnAlign>,
rows: Vec<Vec<MathExpr>>,
},
Align {
rows: Vec<AlignRow>,
numbered: bool,
},
Gather {
rows: Vec<MathExpr>,
numbered: bool,
},
Space(MathSpace),
Phantom {
body: Box<MathExpr>,
},
HPhantom {
body: Box<MathExpr>,
},
VPhantom {
body: Box<MathExpr>,
},
Smash {
body: Box<MathExpr>,
mode: SmashMode,
},
StyleOverride {
style: MathStyle,
body: Box<MathExpr>,
},
FontOverride {
font: MathFont,
body: Box<MathExpr>,
},
Color {
color: String,
body: Box<MathExpr>,
},
Chem {
value: String,
},
Error {
raw: String,
message: String,
},
}Expand description
Structured math expression tree (Section 2.11).
This is a recursive algebraic type representing the parsed structure of a LaTeX
math expression. Box<MathExpr> is used for recursive fields to keep the type
sized.
Variants
Ident
Number
Operator(MathOperator)
Text
Row
Fenced
Superscript
Subscript
Subsuperscript
Frac
Sqrt
Overline
Underline
Overbrace
Underbrace
Overset
Underset
Accent
BigOperator
Matrix
Cases
Array
Align
Gather
Space(MathSpace)
Phantom
HPhantom
VPhantom
Smash
StyleOverride
FontOverride
Color
Chem
Error