pub struct MathOperator {
pub symbol: String,
pub kind: OperatorKind,
}Expand description
A mathematical operator symbol with its classification.
Fields
symbol: Stringkind: OperatorKindTrait Implementations
Sourceimpl Archive for MathOperator
impl Archive for MathOperator
Sourceconst COPY_OPTIMIZATION: CopyOptimization<MathOperator>
const COPY_OPTIMIZATION: CopyOptimization<MathOperator>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedMathOperator
type Archived = ArchivedMathOperator
The archived representation of this type. Read more
Sourcetype Resolver = MathOperatorResolver
type Resolver = MathOperatorResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for MathOperator
impl Clone for MathOperator
Sourcefn clone(&self) -> MathOperator
fn clone(&self) -> MathOperator
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MathOperator
impl Debug for MathOperator
Sourceimpl<'de> Deserialize<'de> for MathOperator
impl<'de> Deserialize<'de> for MathOperator
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<MathOperator, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<MathOperator, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<MathOperator, __D> for <MathOperator as Archive>::Archivedwhere
__D: Fallible + ?Sized,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
OperatorKind: Archive,
<OperatorKind as Archive>::Archived: Deserialize<OperatorKind, __D>,
impl<__D> Deserialize<MathOperator, __D> for <MathOperator as Archive>::Archivedwhere
__D: Fallible + ?Sized,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
OperatorKind: Archive,
<OperatorKind as Archive>::Archived: Deserialize<OperatorKind, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<MathOperator, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<MathOperator, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for MathOperator
impl PartialEq for MathOperator
Sourceimpl<__S> Serialize<__S> for MathOperator
impl<__S> Serialize<__S> for MathOperator
Sourceimpl Serialize for MathOperator
impl Serialize for MathOperator
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for MathOperator
impl StructuralPartialEq for MathOperator